## 0.0.35 - 2025-04-04

* [REFACTOR] converting box ai responses into agnostic dictionaries (561e36e)
* major refactor, box api break up, Alex file and folder operations (1c6ac5d)
* Update version to 0.0.34 and changelog (737c965)